lambeq package
==============

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   lambeq.ccg2discocat
   lambeq.core

Submodules
----------

lambeq.ansatz module
--------------------

.. automodule:: lambeq.ansatz
   :members:
   :undoc-members:
   :show-inheritance:

lambeq.circuit module
---------------------

.. automodule:: lambeq.circuit
   :members:
   :undoc-members:
   :show-inheritance:

lambeq.reader module
--------------------

.. automodule:: lambeq.reader
   :members:
   :undoc-members:
   :show-inheritance:

lambeq.rewrite module
---------------------

.. automodule:: lambeq.rewrite
   :members:
   :undoc-members:
   :show-inheritance:

lambeq.tensor module
--------------------

.. automodule:: lambeq.tensor
   :members:
   :undoc-members:
   :show-inheritance:

lambeq.version module
---------------------

.. automodule:: lambeq.version
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: lambeq
   :members:
   :undoc-members:
   :show-inheritance:
